@@ -11,7 +11,7 @@ use Coro::Channel;
 use Coro::ProcessPool::Process;
 use Coro::ProcessPool::Util qw(cpu_count);
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -92,7 +92,7 @@ sub checkout_proc {
 
 sub process {
     my ($self, $f, $args, $timeout) = @_;
-    ref $f eq 'CODE' || croak 'expected CODE ref to execute';
+    defined $f || croak 'expected CODE ref or task class (string) to execute';
     $args ||= [];
     ref $args eq 'ARRAY' || croak 'expected ARRAY ref of arguments';
 
@@ -178,6 +178,9 @@ Coro::ProcessPool - an asynchronous process pool
         print "$i = " . $deferred{$i}->() . "\n";
     }
 
+    # Use a "task class", implementing 'new' and 'run'
+    my $result = $pool->process('Task::Doubler', 21);
+
     $pool->shutdown;
 
 =head1 DESCRIPTION
@@ -213,7 +216,12 @@ packages used by client code.
 
 Processes code ref C<$f> in a child process from the pool. If C<$args> is
 provided, it is an array ref of arguments that will be passed to C<$f>. Returns
-the result of calling C<$f->(@$args)>.
+the result of calling $f->(@$args).
+
+Alternately, C<$f> may be the name of a class implementing the methods C<new>
+and C<run>, in which case the result is equivalent to calling
+$f->new(@$args)->run(). Note that the include path for worker processes is
+identical to that of the calling process.
 
 This call will yield until the results become available. If all processes are
 busy, this method will block until one becomes available. Processes are spawned
@@ -327,6 +335,12 @@ Then, in your caller:
         Bar::dostuff();
     });
 
+=head2 If it's a problem...
+
+Use the task class method if the loading requirements are causing headaches:
+
+    my $result = $pool->process('Task::Class', [@args]);
+
 =head1 COMPATIBILITY
 
 C<Coro::ProcessPool> will likely break on Win32 due to missing support for
