@@ -4,28 +4,31 @@ use strict;
 use warnings;
 use Carp;
 
-use Coro qw(async cede);
-use Coro::Handle qw(unblock);
-use Coro::AnyEvent qw();
 use Config;
-use IPC::Open3 qw(open3);
-use POSIX qw(:sys_wait_h);
-use String::Escape qw(backslash);
-use Symbol qw(gensym);
-use Coro::ProcessPool::Mailbox;
-use Coro::ProcessPool::Util qw(encode decode $EOL);
+use Coro                        qw(async cede);
+use Coro::AnyEvent              qw();
+use Coro::Handle                qw(unblock);
+use Coro::ProcessPool::Mailbox  qw();
+use Coro::ProcessPool::Util     qw(encode decode $EOL);
+use IPC::Open3                  qw(open3);
+use POSIX                       qw(:sys_wait_h);
+use String::Escape              qw(backslash);
+use Symbol                      qw(gensym);
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
 }
 
-use fields qw(
-    pid
-    child_err
-    child_err_mon
-    processed
-    mailbox
-);
+sub new {
+    my ($class, %param) = @_;
+    return bless {
+        processed     => 0,
+        pid           => undef,
+        child_err     => undef,
+        child_err_mon => undef,
+        mailbox       => undef,
+    }, $class;
+}
 
 sub DESTROY {
     if ($_[0] && $_[0]->{pid}) {
@@ -34,13 +37,6 @@ sub DESTROY {
     }
 }
 
-sub new {
-    my ($class, %param) = @_;
-    my $self = fields::new($class);
-    $self->{processed} = 0;
-    return $self;
-}
-
 #-------------------------------------------------------------------------------
 # Return the full path to the perl binary used to launch the parent in order to
 # ensure that children are run on the same perl version.
@@ -65,7 +61,7 @@ sub get_args {
 # on failure.
 #-------------------------------------------------------------------------------
 sub spawn {
-    my ($self) = @_;
+    my $self = shift;
     my ($r, $w, $e) = (gensym, gensym, gensym);
 
     my $cmd  = $self->get_command_path;
