@@ -8,7 +8,9 @@ use Coro::AnyEvent;
 use Coro::Channel;
 use Coro::Handle;
 use Coro::ProcessPool::Util qw(encode decode $EOL);
+use Devel::StackTrace;
 use Guard qw(scope_guard);
+use Module::Load qw(load);
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -67,8 +69,30 @@ sub start {
 sub process_task {
     my ($class, $task) = @_;
     my ($f, $args) = @$task;
-    my $result = eval { $f->(@$args) };
-    return $@ ? [1, $@] : [0, $result];
+
+    my $result = eval {
+        if (ref $f && ref $f eq 'CODE') {
+            $f->(@$args);
+        } else {
+            load $f;
+            die "method new() not found for class $f" unless $f->can('run');
+            die "method run() not found for class $f" unless $f->can('run');
+            my $obj = $f->new(@$args);
+            $obj->run;
+        }
+    };
+
+    if ($@) {
+        my $error = $@;
+        my $trace = Devel::StackTrace->new(
+            message      => $error,
+            indent       => 1,
+            ignore_class => [$class, 'Coro', 'AnyEvent'],
+        );
+        return [1, $trace->as_string];
+    }
+
+    return [0, $result];
 }
 
 1;
